#ifndef DOCUMENTTYPE_H
#define DOCUMENTTYPE_H

#include <QObject>
#include <QString>

class DocumentType : public QObject
{
    Q_OBJECT

    // properties for QtScript access
    Q_PROPERTY(QString name WRITE setName READ name)
    Q_PROPERTY(QString category WRITE setCategory READ category)
    Q_PROPERTY(QString description WRITE setDescription READ description)
    Q_PROPERTY(QString icon WRITE setIcon READ icon)

    public:
        DocumentType() {}
        DocumentType(const DocumentType &d) { m_name = d.m_name; m_category = d.m_category; m_description = d.m_description; m_icon = d.m_icon; }
        DocumentType(const QString &name, const QString &category, const QString &description, const QString &icon = ""): m_name(name), m_category(category), m_description(description), m_icon(icon) {}

        DocumentType& operator=(const DocumentType &d) { m_name = d.m_name; m_category = d.m_category; m_description = d.m_description; m_icon = d.m_icon; return *this; }
        bool operator==(const DocumentType &a) const { return (*this == a); }

        QString name() const { return m_name; }
        QString category() const { return m_category; }
        QString description() const { return m_description; }
        QString icon() const { return m_icon; }
        QString plugin() const { return m_plugin; }

        void setName(const QString &s) { m_name = s; }
        void setCategory(const QString &s) { m_category = s; }
        void setDescription(const QString &s) { m_description = s; }
        void setIcon(const QString &s) { m_icon = s; }
        void setPlugin(const QString &s) { m_plugin = s; }

    private:
        QString m_name;             // name of the document type (e.g.: Basic EPC Model)
        QString m_category;             // category of the document type        --> EPC <--
                                    //                                           |- Basic
                                    //                                           |- Advanced
        QString m_description;
        QString m_icon;
        QString m_plugin;           // if the document type is scripted this should be set to the name of the Script (from the desktop file)
};

#endif /* DOCUMENTTYPE_H */

